@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2018-2019 The pyXem developers
+# Copyright 2018-2020 the orix developers
 #
 # This file is part of orix.
 #
@@ -19,6 +19,14 @@
 import numpy as np
 
 
+# Lists what will be imported when calling "from orix.base import *"
+__all__ = [
+    "check",
+    "DimensionError",
+    "Object3d",
+]
+
+
 def check(obj, cls):
     if not isinstance(obj, cls):
         try:
