@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2018-2019 The pyXem developers
+# Copyright 2018-2020 the orix developers
 #
 # This file is part of orix.
 #
@@ -32,7 +32,6 @@ domain of an adjusted 432 symmetry.
    :align: center
 
 Rotations or orientations can be inside or outside of an orientation region.
-
 """
 
 import itertools
@@ -111,8 +110,8 @@ def get_proper_groups(Gl, Gr):
 
 
 class OrientationRegion(Rotation):
-    """A set of :obj:`Rotation`s which are the normals of an orientation region.
-
+    """A set of :class:`~orix.quaternion.rotation.Rotation` which are the
+    normals of an orientation region.
     """
 
     @classmethod
@@ -127,8 +126,6 @@ class OrientationRegion(Rotation):
         s1, s2 = get_proper_groups(s1, s2)
         large_cell_normals = _get_large_cell_normals(s1, s2)
         disjoint = s1 & s2
-        # if s1._tuples == s2._tuples:
-        #     disjoint = disjoint.laue
         fundamental_sector = disjoint.fundamental_sector()
         fundamental_sector_normals = Rotation.from_neo_euler(
             AxAngle.from_axes_angles(fundamental_sector, np.pi)
@@ -179,6 +176,10 @@ class OrientationRegion(Rotation):
         return faces
 
     def __gt__(self, other):
+        """Overridden greater than method. Applying this to an Orientation
+        will return only orientations those that lie within the OrientationRegion
+        """
+
         c = Quaternion(self).dot_outer(Quaternion(other)).data
         inside = np.logical_or(
             np.all(np.greater_equal(c, -EPSILON), axis=0),
